CreateSecretResponse class

Constructors

CreateSecretResponse({String? arn, String? name, String? versionId})
CreateSecretResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the secret that you just created.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The friendly name of the secret that you just created.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionId → String?
The unique identifier associated with the version of the secret you just created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited