DeleteResourcePolicyResponse class

Constructors

DeleteResourcePolicyResponse({String? arn, String? name})
DeleteResourcePolicyResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the secret that the resource-based policy was deleted for.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The friendly name of the secret that the resource-based policy was deleted for.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited