DescribeSecretResponse class

Constructors

DescribeSecretResponse({String? arn, DateTime? createdDate, DateTime? deletedDate, String? description, String? kmsKeyId, DateTime? lastAccessedDate, DateTime? lastChangedDate, DateTime? lastRotatedDate, String? name, String? owningService, bool? rotationEnabled, String? rotationLambdaARN, RotationRulesType? rotationRules, List<Tag>? tags, Map<String, List<String>>? versionIdsToStages})
DescribeSecretResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the secret.
final
createdDate → DateTime?
The date that the secret was created.
final
deletedDate → DateTime?
This value exists if the secret is scheduled for deletion. Some time after the specified date and time, Secrets Manager deletes the secret and all of its versions.
final
description → String?
The user-provided description of the secret.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The ARN or alias of the AWS KMS customer master key (CMK) that's used to encrypt the SecretString or SecretBinary fields in each version of the secret. If you don't provide a key, then Secrets Manager defaults to encrypting the secret fields with the default AWS KMS CMK (the one named awssecretsmanager) for this account.
final
lastAccessedDate → DateTime?
The last date that this secret was accessed. This value is truncated to midnight of the date and therefore shows only the date, not the time.
final
lastChangedDate → DateTime?
The last date and time that this secret was modified in any way.
final
lastRotatedDate → DateTime?
The most recent date and time that the Secrets Manager rotation process was successfully completed. This value is null if the secret has never rotated.
final
name → String?
The user-provided friendly name of the secret.
final
owningService → String?
Returns the name of the service that created this secret.
final
rotationEnabled → bool?
Specifies whether automatic rotation is enabled for this secret.
final
rotationLambdaARN → String?
The ARN of a Lambda function that's invoked by Secrets Manager to rotate the secret either automatically per the schedule or manually by a call to RotateSecret.
final
rotationRules → RotationRulesType?
A structure that contains the rotation configuration for this secret.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The list of user-defined tags that are associated with the secret. To add tags to a secret, use TagResource. To remove tags, use UntagResource.
final
versionIdsToStages → Map<String, List<String>>?
A list of all of the currently assigned VersionStage staging labels and the VersionId that each is attached to. Staging labels are used to keep track of the different versions during the rotation process.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited