GetSecretValueResponse class

Constructors

GetSecretValueResponse({String? arn, DateTime? createdDate, String? name, Uint8List? secretBinary, String? secretString, String? versionId, List<String>? versionStages})
GetSecretValueResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the secret.
final
createdDate → DateTime?
The date and time that this version of the secret was created.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The friendly name of the secret.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretBinary → Uint8List?
The decrypted part of the protected secret information that was originally provided as binary data in the form of a byte array. The response parameter represents the binary data as a base64-encoded string.
final
secretString → String?
The decrypted part of the protected secret information that was originally provided as a string.
final
versionId → String?
The unique identifier of this version of the secret.
final
versionStages → List<String>?
A list of all of the staging labels currently attached to this version of the secret.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited