RotateSecretResponse class

Constructors

RotateSecretResponse({String? arn, String? name, String? versionId})
RotateSecretResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the secret.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The friendly name of the secret.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionId → String?
The ID of the new version of the secret created by the rotation started by this request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited