UpdateSecretResponse class

Constructors

UpdateSecretResponse({String? arn, String? name, String? versionId})
UpdateSecretResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the secret that was updated.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The friendly name of the secret that was updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionId → String?
If a new version of the secret was created by this operation, then VersionId contains the unique identifier of the new version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited